//////////////////////////////////////////////////////////////////////
//
// $Workfile: Wldv32.h $
// $Archive: /LonProdukte/Share/Include/Wldv32.h $
//
// Purpose: include file for the exported DLL functions in WLDV32.DLL
//
// Environment: user mode
//
// $Author: Schober $
//
// Copyright (c) 1998-2003 Gesytec GmbH
//
//////////////////////////////////////////////////////////////////////

#if !defined(WLDV32_H)
#define WLDV32_H

#ifndef _WINDOWS_
  #error Please include first <windows.h> or <afxwin.h>
#endif


// Network driver return codes 
typedef enum {
	LDV_OK				= 0,    // all done
	LDV_NOT_FOUND		= 1,
	LDV_ALREADY_OPEN	= 2,    // WLDV32 has already been opened
	LDV_NOT_OPEN		= 3,    // WLDV32 must have been opened for this call
	LDV_DEVICE_ERROR	= 4,    // error during write to device
	LDV_NO_MSG_AVAIL	= 6,    // no data ready from interface
	LDV_NO_BUFF_AVAIL	= 7,    // no message buffer to store neuron id
	LDV_NO_RESOURCES	= 8,
	LDV_OPEN_ERROR		= -1,   // invalid device name
	LDV_NO_LICENSE		= -2,   // WLDV has not been registered for this device
	LDV_NOT_CONNECTED	= -3,   // Communication with the device failed
	//new codes in multi-client version
	LDV_NO_DRIVER		= -4,   // LON driver not found
	LDV_COMERROR		= -5,   // communication error
	LDV_NO_THREAD		= -6,   // no listening thread
	LDV_HANDLE_INVALID  = -7,   // wrong handle passed by client
	LDV_OTHERDEVICE		= -8,   // open device uses another driver
	LDV_NOPIPE			= -9,   // pipe server/client not created
	LDV_READPIPE		= -10,  // pipe read / write error
	LDV_READNEURONID	= -11   // error reading licence data
} LDVCode;

typedef int LNI;


#if !defined(RC_INCLUDE)

#if !defined(_DLLEXPORT_)

// If _DLLEXPORT_ is not defined then the default is to import.
#if defined(__cplusplus)
#define DLLENTRY extern "C" __declspec(dllimport)
#define STDENTRY extern "C" __declspec(dllimport) HRESULT WINAPI
#define STDENTRY_(type) extern "C" __declspec(dllimport) type WINAPI
#else
#define DLLENTRY __declspec(dllimport)
#define STDENTRY __declspec(dllimport) HRESULT WINAPI
#define STDENTRY_(type) __declspec(dllimport) type WINAPI
#endif

#else  // _DLLEXPORT_
// Else if _DLLEXPORT_ is defined then we've been told to export.

#if defined(__cplusplus)
#define DLLENTRY extern "C" __declspec(dllexport)
#define STDENTRY extern "C" __declspec(dllexport) HRESULT WINAPI
#define STDENTRY_(type) extern "C" __declspec(dllexport) type WINAPI
#else
#define DLLENTRY __declspec(dllexport)
#define STDENTRY __declspec(dllexport) HRESULT WINAPI
#define STDENTRY_(type) __declspec(dllexport) type WINAPI
#endif

#endif // _DLLEXPORT_

// Here is the list of service APIs offered by the DLL (using the
//   appropriate entry API declaration macros just #defined above).
STDENTRY_(char*)   ldv_get_version(void);
STDENTRY_(LNI)     ldv_open(char* device_name);
STDENTRY_(LDVCode) ldv_close(LNI handle);
STDENTRY_(LDVCode) ldv_read(LNI handle, void* msg_p, unsigned length);
STDENTRY_(LDVCode) ldv_write(LNI handle, void* msg_p, unsigned length);
STDENTRY_(LDVCode) ldv_register(LNI handle, void (*func_p)(void));
STDENTRY_(LDVCode) ldv_debugmode(char* name, int mode);
STDENTRY_(LDVCode) ldv_neuronID(void* msg_p);


// Function pointer types for dynamic dll loading
typedef char*   (WINAPI *WLDV_GET_VERSION)(void);
typedef LNI     (WINAPI *WLDV_OPEN)(char* device_name);
typedef LDVCode (WINAPI *WLDV_CLOSE)(LNI handle);
typedef LDVCode (WINAPI *WLDV_READ)(LNI handle, void* msg_p, unsigned length);
typedef LDVCode (WINAPI *WLDV_WRITE)(LNI handle, void* msg_p, unsigned length);
typedef LDVCode (WINAPI *WLDV_REGISTER)(LNI handle, void (*func_p)(void));
typedef LDVCode (WINAPI *WLDV_DEBUGMODE)(char* name, int mode);
typedef LDVCode (WINAPI *WLDV_NEURONID)(void* msg_p);


#endif // RC_INCLUDE

#endif // WLDV32_H
